<template>
    <div>
        <el-input
            type="text"
            placeholder="請輸入關鍵字"
            class="mb-30 pam-clientReserved-input"
            v-model="keyWord"
            @keyup.enter.native="search"
        >
            <i slot="suffix" class="icon-search search cursor--pointer" @click="search"></i>
        </el-input>

        <ClientList
            :clients="pageList"
            :title="'reservedList'"
        ></ClientList>

        <UiPagination
            :totalList="filterList"
            @changePage="changePage"
        ></UiPagination>
    </div>
</template>

<script lang="ts">
import { Vue, Component, State, Watch } from 'nuxt-property-decorator';

import { ClientInfo } from '~/assets/ts/models/client.model';

@Component
export default class ClientReservedList extends Vue {

    @State('myAppointmentList')
    myAppointmentList!: ClientInfo[];

    appointmentList: ClientInfo[] = [];
    pageList: ClientInfo[] = [];
    keyWord: string = '';
    filterList: ClientInfo[] = [];

    //////////////////////////////////////////////////////////////////////

    mounted() {
        this.onMyAppointmentListChange();
    }

    //////////////////////////////////////////////////////////////////////

    @Watch('myAppointmentList')
    onMyAppointmentListChange(): void {
      const unreadList = this.myAppointmentList
          .filter((item) => item.communicateStatus !== 'contacted' && !item.consultantReadTime)
          .map((item) => ({ ...item, sortTime: new Date(item.appointmentDate)}))
          .sort((preItem, nextItem) => +nextItem.sortTime - +preItem.sortTime);

      const readList = this.myAppointmentList
          .filter(item => item.communicateStatus !== 'contacted' && item.consultantReadTime)
          .map((item) => ({ ...item, sortTime: new Date(item.consultantReadTime)}))
          .sort((preItem, nextItem) => +nextItem.sortTime - +preItem.sortTime);

      this.appointmentList = unreadList.concat(readList);
      this.filterList = this.appointmentList;
    }

    search(): void {
        this.filterList = this.appointmentList.filter(item => {
            return item.name.match(this.keyWord) || item.requirement.match(this.keyWord)
        })
    }

    changePage(pageList: ClientInfo[]): void {
        this.pageList = pageList;
    }

}
</script>
